@@ -31,8 +31,6 @@ from pynitrokey.cli.storage import storage
 from pynitrokey.confconsts import LOG_FN, LOG_FORMAT
 from pynitrokey.helpers import filter_sensitive_parameters, local_critical
 
-# from . import _patches  # noqa  (since otherwise "unused")
-
 logger = logging.getLogger(__name__)
 
 
@@ -72,7 +70,6 @@ def nitropy():
         "ecdsa",
         "fido2",
         "pyusb",
-        "spsdk",
     ]
     for x in pymodules:
         logger.info(f"{x} version: {package_version(x)}")
@@ -85,6 +82,10 @@ def nitropy():
     check_root()
 
 
+from . import nkfido2
+
+nkfido2.add_commands(fido2)
+
 nitropy.add_command(fido2)
 nitropy.add_command(nethsm)
 nitropy.add_command(nk3)
