@@ -18,7 +18,6 @@ from nitrokey.trussed import Fido2Certs, TrussedBase, TrussedDevice, Uuid, Versi
 from tqdm import tqdm
 
 from pynitrokey.cli.trussed.test import TestContext, TestResult, TestStatus, test_case
-from pynitrokey.fido2.client import NKFido2Client
 from pynitrokey.helpers import local_print
 
 logger = logging.getLogger(__name__)
@@ -339,10 +338,12 @@ def test_fido2(ctx: TestContext, device: TrussedBase) -> TestResult:
         return TestResult(TestStatus.SKIPPED)
 
     # drop out early, if pin is needed, but not provided
-    nk_client = NKFido2Client()
-    nk_client.find_device(device.device)
+    from fido2.client import Fido2Client
 
-    if nk_client.has_pin() and not ctx.pin:
+    fido2_client = Fido2Client(device=device.device, origin="https://example.org")
+    has_pin = fido2_client.info.options["clientPin"]
+
+    if has_pin and not ctx.pin:
         return TestResult(
             TestStatus.FAILURE,
             "FIDO2 pin is set, but not provided (use the --pin argument)",
@@ -350,16 +351,28 @@ def test_fido2(ctx: TestContext, device: TrussedBase) -> TestResult:
 
     # Based on https://github.com/Yubico/python-fido2/blob/142587b3e698ca0e253c78d75758fda635cac51a/examples/credential.py
 
-    from fido2.client import Fido2Client, PinRequiredError, UserInteraction
+    from fido2.attestation.base import InvalidSignature
+    from fido2.attestation.packed import PackedAttestation
+    from fido2.client import PinRequiredError, UserInteraction
     from fido2.server import Fido2Server
     from fido2.webauthn import (
         AttestationConveyancePreference,
+        AttestationObject,
         AuthenticatorAttachment,
         PublicKeyCredentialRpEntity,
         PublicKeyCredentialUserEntity,
         UserVerificationRequirement,
     )
 
+    def verify_attestation(
+        attestation_object: AttestationObject, client_data_hash: bytes
+    ) -> None:
+        verifier = PackedAttestation()
+        assert attestation_object.fmt == verifier.FORMAT
+        verifier.verify(
+            attestation_object.att_stmt, attestation_object.auth_data, client_data_hash
+        )
+
     class NoInteraction(UserInteraction):
         def __init__(self, pin: Optional[str]) -> None:
             self.pin = pin
@@ -382,6 +395,7 @@ def test_fido2(ctx: TestContext, device: TrussedBase) -> TestResult:
     server = Fido2Server(
         PublicKeyCredentialRpEntity(id="example.com", name="Example RP"),
         attestation=AttestationConveyancePreference.DIRECT,
+        verify_attestation=verify_attestation,
     )
     uv = UserVerificationRequirement.DISCOURAGED
     user = PublicKeyCredentialUserEntity(id=b"user_id", name="A. User")
@@ -412,11 +426,14 @@ def test_fido2(ctx: TestContext, device: TrussedBase) -> TestResult:
                 f"Unexpected FIDO2 cert hash for version {firmware_version}: {cert_hash}",
             )
 
-    auth_data = server.register_complete(
-        state,
-        make_credential_result.client_data,
-        make_credential_result.attestation_object,
-    )
+    try:
+        auth_data = server.register_complete(
+            state,
+            make_credential_result.client_data,
+            make_credential_result.attestation_object,
+        )
+    except InvalidSignature:
+        return TestResult(TestStatus.FAILURE, "Invalid attestation signature")
     if not auth_data.credential_data:
         return TestResult(TestStatus.FAILURE, "Missing credential data in auth data")
     credentials = [auth_data.credential_data]
