@@ -67,6 +67,4 @@ CLI_LOG_BLACKLIST: dict[str, int] = {
 GH_ISSUES_URL = "https://github.com/Nitrokey/pynitrokey/issues/"
 SUPPORT_URL = "https://support.nitrokey.com/"
 SUPPORT_EMAIL = "support@nitrokey.com"
-UDEV_URL = (
-    "https://docs.nitrokey.com/nitrokey3/linux/firmware-update.html#troubleshooting"
-)
+UDEV_URL = "https://docs.nitrokey.com/nitrokeys/nitrokey3/firmware-update#troubleshooting-linux"
