@@ -17,11 +17,11 @@ import time
 from getpass import getpass
 from importlib.metadata import version
 from itertools import chain
-from numbers import Number
 from threading import Event, Timer
-from typing import Any, Callable, Dict, List, NoReturn, Optional, Tuple, TypeVar, Union
+from typing import Any, Callable, List, Optional, Tuple, TypeVar, Union
 
 import click
+from nitrokey.updates import Repository
 from semver.version import Version
 from tqdm import tqdm
 
@@ -34,7 +34,6 @@ from pynitrokey.confconsts import (
     VERBOSE,
     Verbosity,
 )
-from pynitrokey.updates import Repository
 
 STDOUT_PRINT = True
 
